unit imptextout32;
(** 	IMPORT UNIT FOR TEXTOUT32.UCD
	Code (c)1998 Gordon Bamber (gbamber@mistral.co.uk)
	Freeware for personal use.
	Source code and copyright available for money.
	Delphi V2 and V3
**)

interface
Uses Windows;

(** Each function is preceeded with a description of it's parameters/use **)

(** A simple About Box with the function definitions displayed **)
Procedure DLLAbout;stdcall;

(** The main function.
    Parameters are:
    1) hWind = A valid Window Handle on which text can be written
       All co-ordinates are relative to the TopLeft corner of this window client area
    2) (Pixels) StartX, StartY are the co-ordinates at which the text will start
    3) (Pixels) EndX is the wrapping point. A newline will not be triggered unless:
	a) A pipe (|) character is encountered
	b) A #13 or #10 or #13#10 pair is encountered
	c) The wrapping point has been exceeded AND a space is encountered.
    4) FontSize is in points
    5) Fontcolor is either:
	a) A fixed number from 1 -> 38 (see COLOURS.TXT for values)
	b) An RGB triplet longint above 38
    6) Fontname is the face name i.e.  'Ariel' 'Times New Roman'
	A font style can be appended to the name i.e. 'Arial+Bold', 'Ariel+Italic'
    7) Text can be any length. High-ASCII characters will not be printed.
    8) (sec/100) Milliseconds is the pause between character prints
    9) (True/False) If EOLPause is true, then printing pauses after:
	a) (FullStop, Colon, Semicolon, Question Mark, Exclamation Mark) for 500ms
	b) Comma for 200ms
   10) (0->5) If SoundNum is nonzero, then a built-in sound followes each character.
   11) (Pixels) aLeft,aTop,aWidth,aHeight define a 'hot-spot' in the window.
	If the mouse is clicked in this area, then printing will stop.
**)
Procedure WriteText(hWind:THANDLE;StartX,StartY,EndX,FontSize:Integer;FontColor:LongInt;
aFontName,Text:PChar;Milliseconds:Longint;EOLPause:WordBool;SoundNum,
aleft,atop,awidth,aheight:Word);stdcall;

(** Call this function to stop the current print. In some apps, it will not work,
    so in those cases, use the 'hot-spot method instead **)
(** In all cases, pressing Function key 11 during printing will stop printing **)
Procedure StopWriting;stdcall;

(** After this function is called, then all calls to WriteText return immediately **)
Procedure DisableWriting;stdcall;

(** Call this to undo the effects of DisableWriting **)
Procedure EnableWriting;stdcall;

implementation
Procedure DLLAbout;external 'TEXTOUT32.U32';
Procedure WriteText(hWind:THANDLE;StartX,StartY,EndX,FontSize:Integer;FontColor:LongInt;
aFontName,Text:PChar;Milliseconds:Longint;EOLPause:WordBool;SoundNum,
aleft,atop,awidth,aheight:Word);external 'TEXTOUT32.U32';
Procedure StopWriting;external 'TEXTOUT32.U32';
Procedure EnableWriting;external 'TEXTOUT32.U32';
Procedure DisableWriting;external 'TEXTOUT32.U32';

end.
 